==> crm-commom-vo-1.1.7.1.2.release.jar: com/biz/crm/nebular/mdm/customer/MdmCustomerDockingRespVo.java <==
package com.biz.crm.nebular.mdm.customer;
import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;

/**
 * 返回vo
 *
 * @author zxw
 * @date 2020-09-02 14:10:25
 */
@EqualsAndHashCode(callSuper = true)
@Data
@ApiModel(value = "客户信息对接人")
@SaturnEntity(name = "MdmCustomerDockingRespVo", description = "客户信息对接人")
public class MdmCustomerDockingRespVo extends CrmExtVo {

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("职位编码")
    @SaturnColumn(description = "职位编码")
    private String positionCode;

    @ApiModelProperty("职位名称")
    @SaturnColumn(description = "职位名称")
    private String positionName;

    @ApiModelProperty("组织编码")
    @SaturnColumn(description = "组织编码")
    private String orgCode;

    @SaturnColumn(description = "组织名称")
    @ApiModelProperty("组织名称")
    private String orgName;

    @SaturnColumn(description = "用户帐号")
    @ApiModelProperty("用户帐号")
    private String userName;

    @ApiModelProperty("用户名称")
    private String fullName;

    @ApiModelProperty("联系人电话")
    @SaturnColumn(description = "联系人电话")
    private String contactPhone;

    @SaturnColumn(description = "渠道")
    @ApiModelProperty("渠道")
    private String channel;

    @ApiModelProperty("二批商")
    @SaturnColumn(description = "二批商")
    private String secondCustomerCode;

}

==> crm-commom-vo-1.3.0.6.61.release.jar: com/biz/crm/nebular/mdm/customer/MdmCustomerDockingRespVo.java <==
package com.biz.crm.nebular.mdm.customer;
import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;

import java.util.List;

/**
 * 返回vo
 *
 * @author zxw
 * @date 2020-09-02 14:10:25
 */
@EqualsAndHashCode(callSuper = true)
@Data
@ApiModel(value = "客户信息对接人")
@SaturnEntity(name = "MdmCustomerDockingRespVo", description = "客户信息对接人")
public class MdmCustomerDockingRespVo extends CrmExtVo {

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("职位编码")
    @SaturnColumn(description = "职位编码")
    private String positionCode;

    @ApiModelProperty("职位名称")
    @SaturnColumn(description = "职位名称")
    private String positionName;

    @ApiModelProperty("组织编码")
    @SaturnColumn(description = "组织编码")
    private String orgCode;

    @SaturnColumn(description = "组织名称")
    @ApiModelProperty("组织名称")
    private String orgName;

    @SaturnColumn(description = "用户帐号")
    @ApiModelProperty("用户帐号")
    private String userName;

    @ApiModelProperty("用户名称")
    private String fullName;

    @ApiModelProperty("联系人电话")
    @SaturnColumn(description = "联系人电话")
    private String contactPhone;

    @SaturnColumn(description = "渠道")
    @ApiModelProperty("渠道")
    private String channel;

    @ApiModelProperty("二批商")
    @SaturnColumn(description = "二批商")
    private String secondCustomerCode;

    @ApiModelProperty("销售公司编码")
    private String saleCompany;

    @ApiModelProperty("客户供货关系列表")
    private List<MdmCustomerSupplyDetailRespVo> mdmCustomerSupplyDetailVos;

}
